@@ -205,8 +205,7 @@ class FacileToolkit2:
         for locator in locators:
             lista_presente = BuiltIn().run_keyword_and_return_status("Wait Until Element is Visible", locator, timeout)
             if lista_presente:
-                self.select_from_list_random_index(locator=locator, start_index=start_index, end_index=end_index,
-                                                   timeout=timeout)\
+                self.select_from_list_random_index(locator=locator, start_index=start_index, end_index=end_index, timeout=timeout) 
 
     @keyword
     def i_land_on_page(self, url, timeout="60s"):
@@ -290,7 +289,8 @@ class FacileToolkit2:
 
     @keyword
     def select_first_autocomplete_option(self,
-                                         locator_option="css:.autocomplete-suggestions:not([style*='display']):not([style*='none']) strong",
+                                         locator_option="css:.autocomplete-suggestions:not([style*='display']):not(["
+                                                        "style*='none']) strong",
                                          timeout=None, error=None):
         """
         Selects the first autocomplete option for auto-complete fields.
@@ -348,9 +348,11 @@ class FacileToolkit2:
             raise AssertionError("Argument is %s, not a list" % type(in_list))
 
     @keyword
-    def error_message_should_be(self, message, error_locator="//span[(contains(@class, 'err') or "
-                                                             "contains(@class, 'wrong')) and "
-                                                             "normalize-space(.)]", timeout=None,
+    def error_message_should_be(self, message,
+                                error_locator="//span[(contains(@class, 'err') or contains(@class, 'wrong')) and "
+                                              "normalize-space(.) and not(.//ancestor::*[contains(@style, "
+                                              "'display:none') or contains(@style, 'display: none')])]",
+                                timeout=None,
                                 case_insensitive=True, match=True):
         """
         Checks if the given error message is present in DOM
@@ -389,7 +391,7 @@ class FacileToolkit2:
     @keyword
     def wait_ajax_optional(self, timeout=None, wait_active=None):
         BuiltIn().run_keyword_and_ignore_error("wait_ajax", timeout, wait_active)
-        
+
     @keyword
     def field_or_parents_should_contain_error(self, locator, timeout=None, error_class="wrong", error=None):
         self.wait_ultil_element_or_parents_contain_class(locator, error_class, timeout, error)
@@ -409,12 +411,14 @@ class FacileToolkit2:
     @keyword
     def fields_should_be_verified(self, *locators, timeout=None, verified_class="verified", error=None):
         for locator in locators:
-            BuiltIn().run_keyword_and_continue_on_failure("field_or_parents_should_be_verified", locator, timeout, verified_class, error)
+            BuiltIn().run_keyword_and_continue_on_failure("field_or_parents_should_be_verified", locator, timeout,
+                                                          verified_class, error)
 
     @keyword
     def fields_should_contain_error(self, *locators, timeout=None, error_class="wrong", error=None):
         for locator in locators:
-            BuiltIn().run_keyword_and_continue_on_failure("field_or_parents_should_contain_error", locator, timeout, error_class, error)
+            BuiltIn().run_keyword_and_continue_on_failure("field_or_parents_should_contain_error", locator, timeout,
+                                                          error_class, error)
 
     @keyword
     def select_checkboxes(self, *locators, timeout="60s"):
@@ -443,15 +447,21 @@ class FacileToolkit2:
     def should_be_checked(self, *locators):
         self.set_selenium_library()
         for locator in locators:
-            is_checked = self.sl.driver.execute_script("return arguments[0].checked || arguments[0].classList.contains('checked');", self.sl.find_element(locator))
-            BuiltIn().run_keyword_and_continue_on_failure("should_be_true", is_checked, "Locator %s is not checked" % locator)
+            is_checked = self.sl.driver.execute_script(
+                "return arguments[0].checked || arguments[0].classList.contains('checked');",
+                self.sl.find_element(locator))
+            BuiltIn().run_keyword_and_continue_on_failure("should_be_true", is_checked,
+                                                          "Locator %s is not checked" % locator)
 
     @keyword
     def should_not_be_checked(self, *locators):
         self.set_selenium_library()
         for locator in locators:
-            is_checked = self.sl.driver.execute_script("return arguments[0].checked || arguments[0].classList.contains('checked');", self.sl.find_element(locator))
-            BuiltIn().run_keyword_and_continue_on_failure("should_not_be_true", is_checked, "Locator %s is checked" % locator)
+            is_checked = self.sl.driver.execute_script(
+                "return arguments[0].checked || arguments[0].classList.contains('checked');",
+                self.sl.find_element(locator))
+            BuiltIn().run_keyword_and_continue_on_failure("should_not_be_true", is_checked,
+                                                          "Locator %s is checked" % locator)
 
     @keyword
     def element_attribute_value_should_not_be(self, locator, attribute, expected, message=None):
@@ -636,7 +646,8 @@ class FacileToolkit2:
 
     def _log_field_values(self):
         try:
-            status, return_value = BuiltIn().run_keyword_and_ignore_error("execute_javascript", "return Array.from(document.querySelectorAll('select, input')).map(p=>{return {id: p.id, value:p.value, text:p.text}})")
+            status, return_value = BuiltIn().run_keyword_and_ignore_error("execute_javascript",
+                                                                          "return Array.from(document.querySelectorAll('select, input')).map(p=>{return {id: p.id, value:p.value, text:p.text}})")
             if status == 'PASS' and return_value is not None:
                 Collections().log_list(list(return_value))
         except:
@@ -649,11 +660,13 @@ class FacileToolkit2:
         BuiltIn().run_keyword_if_test_failed("capture_page_screenshot", "EMBED")
         self.sl.log_location()
         self.sl.close_all_browsers()
-        
+
     def i_see_elements_label(self, *locators):
         self.set_selenium_library()
         for locator in locators:
-            BuiltIn().run_keyword_and_continue_on_failure("element_should_be_visible", "css:label[for='%s']" % self.sl.get_element_attribute(locator, "id"))
+            BuiltIn().run_keyword_and_continue_on_failure("element_should_be_visible",
+                                                          "css:label[for='%s']" % self.sl.get_element_attribute(locator,
+                                                                                                                "id"))
 
     @keyword
     def close_symfony_toolbar(self):
@@ -696,13 +709,17 @@ class FacileToolkit2:
         try:
             self.sl.wait_until_element_is_visible('css:#onetrust-banner-sdk[style*="0px"]', timeout)
         except:
-            if mandatory: raise
-            else: pass
+            if mandatory:
+                raise
+            else:
+                pass
         try:
             self.click_js('id:onetrust-accept-btn-handler')
         except:
-            if mandatory: raise
-            else: pass
+            if mandatory:
+                raise
+            else:
+                pass
 
     def _wait_until(self, condition, error, timeout=None, custom_error=None):
         self.set_selenium_library()
